@@ -11,9 +11,11 @@ import qualified GI.Gtk.Config as Gtk
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "DbusmenuGtk3"
         version = "0.4"
+        pkgName = "gi-dbusmenugtk3"
+        pkgVersion = "0.4.11"
         overridesFile = Just "DbusmenuGtk3.overrides"
         verbose = False
         outputDir = Nothing
